@@ -13,7 +13,7 @@ Archive::Any::Plugin::Rar - Archive::Any wrapper around Archive::Rar
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 =head1 SYNOPSIS
@@ -25,6 +25,7 @@ Do not use this module directly.  Instead, use Archive::Any.
 sub can_handle {
     return(
            'application/x-rar',
+           'application/x-rar-compressed',
           );
 }
 
@@ -38,7 +39,7 @@ sub files {
 sub extract {
     my ( $self, $file ) = @_;
 
-    my $t = Archive::Rar->new( -archive => $file );
+    my $t = Archive::Rar->new( -archive => $file, -quiet   => 'True' );
     return $t->Extract;
 }
 
@@ -59,6 +60,10 @@ Dmitriy V. Simonov, C<< <dsimonov at gmail.com> >>
 
 Thanks to Clint Moore for L<Archive::Any> 
 
+Thanks to C<< <d_ion at mail.ru> >> for minor fix
+
+Thanks to C<< <ksuri at cpan.org> >> for major fix
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2010 Dmitriy V. Simonov.
